穿条纹睡衣的男孩 (豆瓣)
Description: 穿条纹睡衣的男孩电影简介和剧情介绍,穿条纹睡衣的男孩影评、图片、预告片、影讯、论坛、在线购票
Keywords: 穿条纹睡衣的男孩,The Boy in the Striped Pajamas,穿条纹睡衣的男孩影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.65豆瓣电影Top250

# 穿条纹睡衣的男孩 The Boy in the Striped Pajamas (2008)

导演: 马克·赫尔曼
编剧: 约翰·伯恩 / 马克·赫尔曼
主演: 阿萨·巴特菲尔德 / 维拉·法米加 / 卡拉·霍根 / 祖萨·霍尔 / 安贝尔·比蒂 / 拉斯洛·阿隆 / 大卫·休里斯 / 理查德·约翰逊 / 谢拉·汉考克 / 伊凡·弗雷贝利 / 贝拉·费斯彼姆 / 阿提拉·埃杰德 / 鲁伯特·弗兰德 / 大卫·海曼 / 吉姆·诺顿 / 杰克·塞隆 / 米哈利·绍鲍多什 / 泽索特·萨法尔·科夫卡 / 奥索利亚·茱莉娅·帕普
类型: 剧情 / 战争
制片国家/地区: 英国 / 美国
语言: 英语 / 西班牙语
上映日期: 2008-09-12(英国) / 2008-11-07(美国)
片长: 94分钟
又名: 穿条纹衣服的男孩 / 穿条纹衣的男孩
IMDb: tt0914798
豆瓣评分
引用
9.2
527695人评价
5星
63.5%
4星
31.7%
3星
4.4%
2星
0.3%
1星
0.1%
好于 99% 战争片
好于 98% 剧情片
想看 看过
评价:
推荐

## 穿条纹睡衣的男孩的剧情简介 · · · · · ·

八岁男孩布鲁诺（Asa Butterfield 饰）一家随着纳粹军官父亲的一纸调令，由柏林搬迁到了乡下。失去了朋友们的布鲁诺很快对新家附近的“农庄”产生了兴趣，那里有一群身穿“条纹睡衣”的人终日忙碌，并且其中一个为布鲁诺一家服务，他形容肮脏，态度慎微。周遭环境和布鲁诺的举止让母亲暗暗担忧，但纳粹父亲制止家中任何怀疑既定政策的行为。
布鲁诺偷偷结识了铁丝网另一边的同龄男孩施穆尔，并时常带给他食物吃。在紧张的家庭氛围和姐姐向成人世界的变化中，施穆尔是布鲁诺惟一的朋友。某日布鲁诺决定，去铁丝网的另一边，以便见到施穆尔的父亲……
本片根据约翰·伯恩的同名小说改编，获2008年芝加哥国际电影节观众票选奖。 ©豆瓣

## 穿条纹睡衣的男孩的演职员 · · · · · · ( 全部 40 )

- 马克·赫尔曼 导演
- 阿萨·巴特菲尔德 饰 Bruno
- 维拉·法米加 饰 Mother
- 卡拉·霍根 饰 Maria
- 祖萨·霍尔 饰 Berlin Cook
- 安贝尔·比蒂 饰 Gretel

## 穿条纹睡衣的男孩的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片638 · 添加 )

## 穿条纹睡衣的男孩的获奖情况 · · · · · · ( 全部 )

- 第23届西班牙戈雅奖
- 最佳欧洲电影(提名)
- 马克·赫尔曼

## 喜欢这部电影的人也喜欢 · · · · · ·

  拯救大兵瑞恩

  钢琴家

  辛德勒的名单

  1917

  血战钢锯岭

  波斯语课

  敦刻尔克

  美丽人生

  卢旺达饭店

  黑鹰坠落

我要写短评

## 穿条纹睡衣的男孩的短评 · · · · · · ( 全部 118820 条 )

热门 / 最新 / 好友

### 7078 有用 shu 看过 2009-09-09 12:53:07

最后他成为了穿条纹睡衣的男孩。

### 7532 有用 tifanie 看过 2012-10-14 02:46:01

"突然镜头换到那扇黑色大门前，慢慢拉远。 如果你哭了。是为BRUNO对吗？ 那么，shmul呢？"

### 5402 有用 Doublebitch 看过 2010-03-11 11:16:33

无论你之前是什么样的人，在穿上这件条纹睡衣之后，都会变成一样的人。这部电影主题深得我心啊，故事讲得也不错，镜头运用，结局处理都很出色，特别是结尾处那个长达数秒的长镜头发人深省。

### 3375 有用 朝暮雪 看过 2013-01-01 11:28:06

小孩总是交友，大人总是树敌。

### 3472 有用 Sophie Z 看过 2012-04-14 01:14:58

我一直以为会有传统电影中“最后一分钟营救”的那种结局，我一直理所当然地认为主角不死的光环会在这个男孩的身上，以至于看到最后一幕后我很久都没法接受。说到底这是一部纳粹电影。

> 更多短评 118820条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 穿条纹睡衣的男孩的影评 · · · · · · ( 全部 1911 条 )

热门 / 最新 / 好友
小Q 2009-02-24 17:37:09

## 悲剧的诞生

悲剧的诞生 ——观《穿条纹睡衣的男孩》 那里有湛蓝的天空，白色的云，那院子有大树环绕，后来还有了摇曳的秋千架。那里是盛夏的乡村，是理想中的乐园，但又的确是凶宅。那里，有无数的生命在小心翼翼地活着，卑躬屈膝，只为苟延残喘，更有无数的生命不明不白地死去。你... (展开)
1760 173 151回应 收起
四明 2009-01-28 01:00:56

## 理性未来之前

这篇影评可能有剧透

影片的第29秒，出现了John Betjeman的一句话： Childhood is measured out by sounds and smells and sights, before the dark hour of reason grows. 我把它蹩脚地翻成了： 在黑暗的理性到来之前，用以丈量童年的是听觉、嗅觉以及视觉。 这句话有几个地方没有翻准确。其一当然... (展开)
1336 119 180回应 收起
K先森 2009-02-15 20:04:42

## 那扇沉重的铁门

* 蓝蓝的天空： 阳光、大树、秋千； 威严的父亲、美丽的母亲、情窦初开的姐姐； 还有削土豆的沉默医生、穿着条纹睡衣的同龄男孩； 父母对BRUNO的爱，老爷子教师的唠唠叨叨，孩子间纯真的友谊； 这部电影拥有一部讲述美好孩童时代、一部充满诗意的影片所应有的要素。 　　　　 ... (展开)
794 50 47回应 收起
茶 2009-05-27 14:57:29

## 在为Bruno难过的时候能不能带上shmuel?

这篇影评可能有剧透

很多人为Bruno难过 潜意识里大家都觉得，shmuel死了就死了，他是集中营里的孩子，生死早已是定局 而Bruno多无辜啊，纯洁的眼睛湛蓝的小天使 那些犹太的孩子，他们也曾穿戴整齐可爱如安琪儿，他们也爱吃甜食，他们也以自己的爸爸为荣，他们也想做冒险游戏 ... (展开)
668 16 81回应 收起
苏乏 2009-06-12 16:25:13

## 穿条纹睡衣的男孩：文本的技术性压倒

文 / 苏乏 【作为文学作品改编的电影】 没有比这部小说更适合改编成电影的了，在众多反应二战的题材中，或激烈，或偏执，视角各异，有的以宏大著称，有的以奇诡出位，但如论及故事的浑然天成，对人性冲击的独辟蹊径，以及无法释怀的过失，这部围绕奥斯维辛犹太人集中营但... (展开)
436 84 38回应 收起
eyofoaix 2010-03-13 07:44:59

## 本片的4对父子关系

如预想的一样是很揪心的电影，战争背景下的童真，就完全应了那句对悲剧的定义：见证美好的毁灭 豆瓣上已有很多很好的影评，这一篇浅谈贯穿本片的父子关系 1）最显然的当然是德国男孩布鲁诺和他的纳粹军官父亲。他最初以父亲的军人身份为傲，包括喜爱战机模型，或者索性张开双... (展开)
312 7 30回应 收起
loulou 2009-02-28 10:19:34

## 假如我有一个宝贝

假如我有一个宝贝 我希望他有一双深邃的蓝色眼睛 去透明的看着世界 假如我有一个宝贝 我会给他每天一套可爱又不失庄严的衣服 喏 就象这样 小短西裤 衬衫背心 假如我有一个宝贝 他一定很爱吃甜食 所以每次他祈求的望向我时 我只能说，only 1 piece 假如我有一个宝贝 ... (展开)
393 131 119回应 收起
溡説 2009-03-15 14:36:03

## 天使与恶魔and战争与和平

大部分看过这部片子的人都会为Bruno的死而难过。 他那清澈的眼睛，强烈的好奇心 纯真的样子，在周围所有人都被纳粹所影响的时候他却依然保持着自己纯洁的心。让所有的人们欣然一笑。 和所有这个年龄断的孩子一样，Bruno爱玩，害怕寂寞，想要朋友。对周围的事物有着强烈的好奇... (展开)
135 14 30回应 收起
狐狸先生的货车 2015-10-19 12:53:06

## 致主创：多少影片名利客，机关用尽不如君

在黑暗的理性到来之前，用以丈量寂寞童年的是听觉，嗅觉以及视觉，本片对观影人纯真的侵蚀，可谓毫不留情。 自由奔跑像风一样的童年和小伙伴们，上层阶级的华丽和欢乐party，优雅的女主和冷漠的男主，不关乎选择只关乎责任的士兵，按理说战斗家庭的孩子，不该拥... (展开)
90 17 9回应 收起
维他柠檬茶 2018-05-19 19:38:53

## 他在等我的面包

这篇影评可能有剧透

因为战争小男孩不得不离开熟悉的小伙伴，熟悉的城市，来到一个相对孤僻的小乡村。男主的爸爸是军官，他家里许多不清的仆人，有年长的也有如他一般大的穿条纹睡衣的小男孩。离开熟悉的城市的男主它需要一个小伙伴于是他結识了条纹睡衣的小男孩，男主不懂他为什么生活在铁丝网里... (展开)
60 0回应 收起

> 更多影评 1911篇

添加新讨论

## 讨论区 · · · · · ·

文艺性不错，但牺牲了真实性 | 来自笼之吻 |  | 2022-11-19 19:30:46
人性 | 来自豆友 | 39 回应 | 2022-11-19 16:48:27
有个地方没看懂，求解答 | 来自黄加加 | 26 回应 | 2022-11-14 04:19:23
如果结局是布鲁诺被救了 其他犹太人仍然被处死 会... | 来自tomsweetheart | 7 回应 | 2022-11-13 01:21:31
关门那个好像是那个说只是去洗澡的人 | 来自緋の★鱼 | 5 回应 | 2022-11-12 22:47:34

> 去这部影片的讨论区（全部308条）

## 关于《穿条纹睡衣的男孩》的问题 · · · · · · ( 全部27个 )

- 为什么集中营的其它犹太人想不到挖洞跑出来？ 18人回答
- 为什么不说德语？ 9人回答

> 全部27个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 《午夜场》“天堂电影院”佳片推荐 (影志)
- 德国视角的二战电影（不定期更新） ([己注销])

## 谁在看这部电影 · · · · · ·

- 发条橙.
  1分钟前 想看
- 进击的粉兔
  2分钟前 看过
- 沉默是最好的
  6分钟前 看过

827377人看过 / 397321人想看

订阅穿条纹睡衣的男孩的评论:
feed: rss 2.0